@@ -11,7 +11,7 @@ use tinytemplate::TinyTemplate;
 
 const LC_P: &str = "https://leetcode.com/problems/";
 
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct Quiz {
     title: String,
     level: Level,
@@ -50,6 +50,13 @@ impl FromStr for Level {
     }
 }
 
+#[cfg(feature = "emacs")]
+impl emacs::FromLisp<'_> for Level {
+    fn from_lisp(value: emacs::Value<'_>) -> emacs::Result<Self> {
+        Ok(Level::from_str(&String::from_lisp(value).unwrap()).unwrap())
+    }
+}
+
 impl Quiz {
     pub(super) fn from_resp(resp: Response, source_link: String) -> Result<Self, String> {
         let content = graphql_response_parse(resp)?;
@@ -112,14 +119,14 @@ impl Quiz {
     /// Parse content in template
     pub fn use_fmt_temp(
         &self,
-        temp: &Option<String>,
+        temp: Option<String>,
         code_lang: &Option<String>,
     ) -> Result<String, String> {
         match temp {
             Some(s) => {
                 // make template
                 let mut tt = TinyTemplate::new();
-                tt.add_template("quiz", s).map_err(|e| e.to_string())?;
+                tt.add_template("quiz", &s).map_err(|e| e.to_string())?;
 
                 tt.render(
                     "quiz",
@@ -171,7 +178,6 @@ mod tests {
 
     #[test]
     fn test_fmt_temp() {
-        //let mut q = Quiz::new();
         let s = "README {source}, {title}; {content}..{level}ll{code}";
 
         // make template
@@ -197,5 +203,32 @@ mod tests {
             result,
             "README linklink, titititle; main content..Easyllcodecode"
         );
+
+        // test \n
+        let s = "README {source}\n\n, {title}; {content}..{level}ll{code}";
+        tt.add_template("quiz", s)
+            .map_err(|e| e.to_string())
+            .unwrap();
+
+        let result = tt
+            .render(
+                "quiz",
+                &FmtTemplate {
+                    level: Level::Easy,
+                    source: "linklink".to_string(),
+                    title: "titititle".to_string(),
+                    content: "main content".to_string(),
+                    code_snippet: "codecode".to_string(),
+                },
+            )
+            .unwrap();
+
+        assert_eq!(
+            result,
+            "README linklink
+
+, titititle; main content..Easyllcodecode"
+        );
+        println!("{}", result);
     }
 }
